/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.editingsupport;

import java.util.List;

import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.ComboBoxViewerCellEditor;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.widgets.Composite;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;

/**
 * This class constructs and manages an editing element for the annotation view. It provides a combo
 * box that displays predefined, fixed values from an annotation value provider.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: AC8E4395DB075EC3FA9BF290373BBD9B
 */
public class ComboBoxEditingSupport extends AnnotationEditingSupportBase {
	/** Combo box cell editor */
	private ComboBoxViewerCellEditor cellEditor = null;

	/**
	 * Constructor.
	 * 
	 * @param viewer
	 *            Column viewer
	 * @param clazz
	 *            Annotation class handled by this editing support
	 * @param values
	 *            Values for the combo box
	 */
	public ComboBoxEditingSupport(ColumnViewer viewer,
			Class<? extends IAnnotatedSpecification> clazz, List<String> values) {
		super(viewer, clazz);
		cellEditor = new ComboBoxViewerCellEditor((Composite)getViewer().getControl());
		cellEditor.setLabelProvider(new LabelProvider());
		cellEditor.setContentProvider(new ArrayContentProvider());
		cellEditor.setInput(values);
		cellEditor.getViewer().getCCombo().setEditable(false);
	}

	/** {@inheritDoc} */
	@Override
	protected CellEditor getCellEditor(Object element) {
		return cellEditor;
	}
}
